@@ -2,12 +2,17 @@
 """
 
 from string import hexdigits
-from typing import Any
 from typing import Tuple
+from typing import TypeVar
 from typing import Union
 
+from apyscript.type import Number
+from apyscript.type import String
 
-def validate_hex_color_code_format(hex_color_code: str) -> None:
+StrOrString = TypeVar('StrOrString', str, String)
+
+
+def validate_hex_color_code_format(hex_color_code: StrOrString) -> None:
     """
     Validate a specified hexadecimal color code's format.
 
@@ -22,12 +27,17 @@ def validate_hex_color_code_format(hex_color_code: str) -> None:
     ValueError
         If invalid hex color code specified.
     """
-    if not isinstance(hex_color_code, str):
+    if not isinstance(hex_color_code, (str, String)):
         raise ValueError(
             'Hex color code only supports str type, specified: '
             f'{type(hex_color_code)}')
 
-    char_len: int = len(hex_color_code)
+    if isinstance(hex_color_code, String):
+        value_: str = hex_color_code.value
+    else:
+        value_ = hex_color_code
+
+    char_len: int = len(value_)
     expected_char_lengths: Tuple[int, int, int] = (1, 3, 6)
     if char_len not in expected_char_lengths:
         raise ValueError(
@@ -35,7 +45,7 @@ def validate_hex_color_code_format(hex_color_code: str) -> None:
             f'\nSupported number of digits are: {expected_char_lengths}'
             f'\nSpecified: {hex_color_code} ({char_len} digits)')
 
-    for char in hex_color_code:
+    for char in value_:
         if char in hexdigits:
             continue
         raise ValueError(
@@ -44,7 +54,7 @@ def validate_hex_color_code_format(hex_color_code: str) -> None:
             f'\nSupported characters: {hexdigits}')
 
 
-def validate_alpha_range(alpha: Union[float, Any]) -> None:
+def validate_alpha_range(alpha: Union[float, Number]) -> None:
     """
     Validate specified alpha (opacity) value's range.
 
